#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 annotated-wl-pprint
version:              0.7.0
visibility:           public
id:                   annotated-wl-pprint-0.7.0-LfvIEL94sD0ER9mdrVDak7
key:                  annotated-wl-pprint-0.7.0-LfvIEL94sD0ER9mdrVDak7
license:              BSD-3-Clause
maintainer:           david@davidchristiansen.dk
author:               Daan Leijen, David Raymond Christiansen
homepage:             https://github.com/david-christiansen/annotated-wl-pprint
synopsis:             The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.

category:             Text
abi:                  624cf46aaefc59cf5558c6117966f2ba
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.Leijen
import-dirs:          /usr/lib/ghc-8.10.5/site-local/annotated-wl-pprint-0.7.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/annotated-wl-pprint-0.7.0
hs-libraries:         HSannotated-wl-pprint-0.7.0-LfvIEL94sD0ER9mdrVDak7
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

